# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.administration.authenticated_user.v1 import authenticated_user_service_pb2 as qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2


class AuthenticatedUserStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetDetails = channel.unary_unary(
                '/qwak.administration.authenticated_user.v1.AuthenticatedUser/GetDetails',
                request_serializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetDetailsResponse.FromString,
                )
        self.GetEnvironmentDetails = channel.unary_unary(
                '/qwak.administration.authenticated_user.v1.AuthenticatedUser/GetEnvironmentDetails',
                request_serializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetEnvironmentDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetEnvironmentDetailsResponse.FromString,
                )
        self.GetCloudCredentials = channel.unary_unary(
                '/qwak.administration.authenticated_user.v1.AuthenticatedUser/GetCloudCredentials',
                request_serializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetCloudCredentialsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetCloudCredentialsResponse.FromString,
                )


class AuthenticatedUserServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetDetails(self, request, context):
        """get authenticated user details for Login user only (not for application user)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironmentDetails(self, request, context):
        """get authenticated user's environment details
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCloudCredentials(self, request, context):
        """Get cloud credentials for login user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthenticatedUserServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetails,
                    request_deserializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetDetailsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetDetailsResponse.SerializeToString,
            ),
            'GetEnvironmentDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironmentDetails,
                    request_deserializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetEnvironmentDetailsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetEnvironmentDetailsResponse.SerializeToString,
            ),
            'GetCloudCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCloudCredentials,
                    request_deserializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetCloudCredentialsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetCloudCredentialsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.administration.authenticated_user.v1.AuthenticatedUser', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuthenticatedUser(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.authenticated_user.v1.AuthenticatedUser/GetDetails',
            qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetDetailsRequest.SerializeToString,
            qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironmentDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.authenticated_user.v1.AuthenticatedUser/GetEnvironmentDetails',
            qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetEnvironmentDetailsRequest.SerializeToString,
            qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetEnvironmentDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCloudCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.authenticated_user.v1.AuthenticatedUser/GetCloudCredentials',
            qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetCloudCredentialsRequest.SerializeToString,
            qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetCloudCredentialsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v0/environments/configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7qwak/administration/v0/environments/configuration.proto\x12\x1fqwak.administration.environment\"\x82\x04\n\x1cQwakEnvironmentConfiguration\x12\x19\n\x11\x65\x64ge_services_url\x18\x01 \x01(\t\x12\x1d\n\x15management_access_url\x18\x06 \x01(\t\x12\x15\n\rmodel_api_url\x18\x02 \x01(\t\x12\x1e\n\x16\x61nalytics_data_api_url\x18\x03 \x01(\t\x12\x1d\n\x15object_storage_bucket\x18\x04 \x01(\t\x12\x19\n\x11\x62i_system_api_key\x18\x05 \x01(\t\x12T\n\x13\x63loud_configuration\x18\x07 \x01(\x0b\x32\x37.qwak.administration.environment.QwakCloudConfiguration\x12_\n\x1b\x66\x65\x61ture_store_configuration\x18\x08 \x01(\x0b\x32:.qwak.administration.environment.FeatureStoreConfiguration\x12!\n\x19\x63ontainer_registry_prefix\x18\t \x01(\t\x12]\n\x1a\x63ommunication_manager_type\x18\n \x01(\x0e\x32\x39.qwak.administration.environment.CommunicationManagerType\"v\n\x19\x46\x65\x61tureStoreConfiguration\x12\x1d\n\x15\x61irflow_connection_id\x18\x01 \x01(\t\x12\x15\n\rredis_address\x18\x02 \x01(\t\x12#\n\x1buser_code_execution_allowed\x18\x03 \x01(\x08\"\xdf\x01\n\x16QwakCloudConfiguration\x12Y\n\x17\x61ws_cloud_configuration\x18\x01 \x01(\x0b\x32\x36.qwak.administration.environment.AwsCloudConfigurationH\x00\x12Y\n\x17gcp_cloud_configuration\x18\x02 \x01(\x0b\x32\x36.qwak.administration.environment.GcpCloudConfigurationH\x00\x42\x0f\n\rconfiguration\"\xae\x01\n\x15\x41wsCloudConfiguration\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12K\n\x11\x66\x65\x61ture_store_emr\x18\x03 \x01(\x0b\x32\x30.qwak.administration.environment.FeatureStoreEmr\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x11\n\tworkgroup\x18\x05 \x01(\t\"\x91\x01\n\x15GcpCloudConfiguration\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06region\x18\x02 \x01(\t\x12 \n\x18\x62ig_lake_connection_name\x18\x03 \x01(\t\x12\x19\n\x11\x62ig_lake_location\x18\x04 \x01(\t\x12\x17\n\x0fservice_account\x18\x05 \x01(\t\"\xc5\x01\n\x0f\x46\x65\x61tureStoreEmr\x12\x14\n\x0c\x65\x63\x32_key_name\x18\x01 \x01(\t\x12\x15\n\rec2_subnet_id\x18\x02 \x01(\t\x12\x19\n\x11\x65mr_job_flow_role\x18\x03 \x01(\t\x12\x18\n\x10\x65mr_service_role\x18\x04 \x01(\t\x12%\n\x1d\x65\x63\x32_additional_security_group\x18\x05 \x01(\t\x12)\n!target_on_demand_capacity_workers\x18\x06 \x01(\x05*X\n\x18\x43ommunicationManagerType\x12\x13\n\x0fINVALID_MANAGER\x10\x00\x12\x12\n\x0e\x44IRECT_MANAGER\x10\x01\x12\x13\n\x0f\x41\x44MIRAL_MANAGER\x10\x02\x42\xb2\x01\n\x1e\x63om.qwak.ai.administration.apiP\x01Z\x8d\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0b\x06proto3')

_COMMUNICATIONMANAGERTYPE = DESCRIPTOR.enum_types_by_name['CommunicationManagerType']
CommunicationManagerType = enum_type_wrapper.EnumTypeWrapper(_COMMUNICATIONMANAGERTYPE)
INVALID_MANAGER = 0
DIRECT_MANAGER = 1
ADMIRAL_MANAGER = 2


_QWAKENVIRONMENTCONFIGURATION = DESCRIPTOR.message_types_by_name['QwakEnvironmentConfiguration']
_FEATURESTORECONFIGURATION = DESCRIPTOR.message_types_by_name['FeatureStoreConfiguration']
_QWAKCLOUDCONFIGURATION = DESCRIPTOR.message_types_by_name['QwakCloudConfiguration']
_AWSCLOUDCONFIGURATION = DESCRIPTOR.message_types_by_name['AwsCloudConfiguration']
_GCPCLOUDCONFIGURATION = DESCRIPTOR.message_types_by_name['GcpCloudConfiguration']
_FEATURESTOREEMR = DESCRIPTOR.message_types_by_name['FeatureStoreEmr']
QwakEnvironmentConfiguration = _reflection.GeneratedProtocolMessageType('QwakEnvironmentConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _QWAKENVIRONMENTCONFIGURATION,
  '__module__' : 'qwak.administration.v0.environments.configuration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.QwakEnvironmentConfiguration)
  })
_sym_db.RegisterMessage(QwakEnvironmentConfiguration)

FeatureStoreConfiguration = _reflection.GeneratedProtocolMessageType('FeatureStoreConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESTORECONFIGURATION,
  '__module__' : 'qwak.administration.v0.environments.configuration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.FeatureStoreConfiguration)
  })
_sym_db.RegisterMessage(FeatureStoreConfiguration)

QwakCloudConfiguration = _reflection.GeneratedProtocolMessageType('QwakCloudConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _QWAKCLOUDCONFIGURATION,
  '__module__' : 'qwak.administration.v0.environments.configuration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.QwakCloudConfiguration)
  })
_sym_db.RegisterMessage(QwakCloudConfiguration)

AwsCloudConfiguration = _reflection.GeneratedProtocolMessageType('AwsCloudConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _AWSCLOUDCONFIGURATION,
  '__module__' : 'qwak.administration.v0.environments.configuration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.AwsCloudConfiguration)
  })
_sym_db.RegisterMessage(AwsCloudConfiguration)

GcpCloudConfiguration = _reflection.GeneratedProtocolMessageType('GcpCloudConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _GCPCLOUDCONFIGURATION,
  '__module__' : 'qwak.administration.v0.environments.configuration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.GcpCloudConfiguration)
  })
_sym_db.RegisterMessage(GcpCloudConfiguration)

FeatureStoreEmr = _reflection.GeneratedProtocolMessageType('FeatureStoreEmr', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESTOREEMR,
  '__module__' : 'qwak.administration.v0.environments.configuration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.FeatureStoreEmr)
  })
_sym_db.RegisterMessage(FeatureStoreEmr)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.administration.apiP\001Z\215\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0'
  _COMMUNICATIONMANAGERTYPE._serialized_start=1480
  _COMMUNICATIONMANAGERTYPE._serialized_end=1568
  _QWAKENVIRONMENTCONFIGURATION._serialized_start=93
  _QWAKENVIRONMENTCONFIGURATION._serialized_end=607
  _FEATURESTORECONFIGURATION._serialized_start=609
  _FEATURESTORECONFIGURATION._serialized_end=727
  _QWAKCLOUDCONFIGURATION._serialized_start=730
  _QWAKCLOUDCONFIGURATION._serialized_end=953
  _AWSCLOUDCONFIGURATION._serialized_start=956
  _AWSCLOUDCONFIGURATION._serialized_end=1130
  _GCPCLOUDCONFIGURATION._serialized_start=1133
  _GCPCLOUDCONFIGURATION._serialized_end=1278
  _FEATURESTOREEMR._serialized_start=1281
  _FEATURESTOREEMR._serialized_end=1478
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CollectionEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_ID_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    RETRY_NUMBER_FIELD_NUMBER: builtins.int
    collection_id: builtins.str
    """Unique identifier of the collection against which we're performing the action"""
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the collection was last modified"""
    retry_number: builtins.int
    """How many times this event has been retried already"""
    def __init__(
        self,
        *,
        collection_id: builtins.str = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        retry_number: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_id", b"collection_id", "last_modified_at", b"last_modified_at", "retry_number", b"retry_number"]) -> None: ...

global___CollectionEvent = CollectionEvent



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.feature_store.sources.streaming_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class StreamingSink(google.protobuf.message.Message):
    """This section defines the general sink definitions based on the FS type, i.e.-
    a type for streaming featuresets, a type for batch featuresets etc.
    this is necessary for considerations such as attachment points etc. that are
    inherent to the featureset type and not the concrete sink type


    a sink for a streaming featureset (streaming here means the sink is aware of the online/offline
    jobs and defines which of the jobs it attaches to)
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTACHMENT_POINT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    KAFKA_SINK_FIELD_NUMBER: builtins.int
    @property
    def attachment_point(self) -> global___StreamingAttachmentPoint:
        """The attachment point (i.e., which job is responsible for writing to this sink)"""
    name: builtins.str
    """sink name"""
    @property
    def kafka_sink(self) -> global___KafkaSink:
        """A kafka sink
        NOTE: DO NOT USE field number 3, it's already used above
        """
    def __init__(
        self,
        *,
        attachment_point: global___StreamingAttachmentPoint | None = ...,
        name: builtins.str = ...,
        kafka_sink: global___KafkaSink | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attachment_point", b"attachment_point", "kafka_sink", b"kafka_sink", "sink_type", b"sink_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attachment_point", b"attachment_point", "kafka_sink", b"kafka_sink", "name", b"name", "sink_type", b"sink_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["sink_type", b"sink_type"]) -> typing_extensions.Literal["kafka_sink"] | None: ...

global___StreamingSink = StreamingSink

class KafkaSink(google.protobuf.message.Message):
    """######################### Concrete  Sink Types #########################
    these are concrete sink types (e.g., Kafka, Kinesis)
    the relation of sink-by-fs-type:conrete-sink-type is a many:many relation

    A featureset sink that writes to kafka
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    BOOTSTRAP_SERVERS_FIELD_NUMBER: builtins.int
    MESSAGE_FORMAT_FIELD_NUMBER: builtins.int
    AUTH_CONFIG_FIELD_NUMBER: builtins.int
    topic: builtins.str
    """Target topic"""
    bootstrap_servers: builtins.str
    """bootstrap servers, separated by a comma"""
    message_format: qwak.feature_store.sources.streaming_pb2.MessageFormat.ValueType
    """The format of the messages written to the sink"""
    @property
    def auth_config(self) -> qwak.feature_store.sources.streaming_pb2.Authentication:
        """Auth configuration"""
    def __init__(
        self,
        *,
        topic: builtins.str = ...,
        bootstrap_servers: builtins.str = ...,
        message_format: qwak.feature_store.sources.streaming_pb2.MessageFormat.ValueType = ...,
        auth_config: qwak.feature_store.sources.streaming_pb2.Authentication | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_config", b"auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_config", b"auth_config", "bootstrap_servers", b"bootstrap_servers", "message_format", b"message_format", "topic", b"topic"]) -> None: ...

global___KafkaSink = KafkaSink

class OnlineStreamingAttachmentPoint(google.protobuf.message.Message):
    """######################### Attachment Points #########################

    Attachment Point on the online job of streaming featureset
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___OnlineStreamingAttachmentPoint = OnlineStreamingAttachmentPoint

class OfflineStreamingAttachmentPoint(google.protobuf.message.Message):
    """Attachment Point on the offline job of a streaming featureset"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___OfflineStreamingAttachmentPoint = OfflineStreamingAttachmentPoint

class StreamingAttachmentPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_STREAMING_ATTACHMENT_POINT_FIELD_NUMBER: builtins.int
    OFFLINE_STREAMING_ATTACHMENT_POINT_FIELD_NUMBER: builtins.int
    @property
    def online_streaming_attachment_point(self) -> global___OnlineStreamingAttachmentPoint: ...
    @property
    def offline_streaming_attachment_point(self) -> global___OfflineStreamingAttachmentPoint: ...
    def __init__(
        self,
        *,
        online_streaming_attachment_point: global___OnlineStreamingAttachmentPoint | None = ...,
        offline_streaming_attachment_point: global___OfflineStreamingAttachmentPoint | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attachment_point_type", b"attachment_point_type", "offline_streaming_attachment_point", b"offline_streaming_attachment_point", "online_streaming_attachment_point", b"online_streaming_attachment_point"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attachment_point_type", b"attachment_point_type", "offline_streaming_attachment_point", b"offline_streaming_attachment_point", "online_streaming_attachment_point", b"online_streaming_attachment_point"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["attachment_point_type", b"attachment_point_type"]) -> typing_extensions.Literal["online_streaming_attachment_point", "offline_streaming_attachment_point"] | None: ...

global___StreamingAttachmentPoint = StreamingAttachmentPoint



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/monitoring/v0/alerting_channel_sync_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.monitoring.v0 import alerting_channel_pb2 as qwak_dot_monitoring_dot_v0_dot_alerting__channel__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6qwak/monitoring/v0/alerting_channel_sync_service.proto\x12\x12qwak.monitoring.v0\x1a)qwak/monitoring/v0/alerting_channel.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"d\n)ListAlertingChannelsForEdgeClusterRequest\x12\x37\n\x13sync_channels_since\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"e\n*ListAlertingChannelsForEdgeClusterResponse\x12\x37\n\rsync_response\x18\x01 \x01(\x0b\x32 .qwak.monitoring.v0.SyncResponse\"d\n)ListAlertingChannelsForCoreClusterRequest\x12\x37\n\x13sync_channels_since\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"e\n*ListAlertingChannelsForCoreClusterResponse\x12\x37\n\rsync_response\x18\x01 \x01(\x0b\x32 .qwak.monitoring.v0.SyncResponse2\xe8\x02\n\x1a\x41lertingChannelSyncService\x12\xa3\x01\n\"ListAlertingChannelsForEdgeCluster\x12=.qwak.monitoring.v0.ListAlertingChannelsForEdgeClusterRequest\x1a>.qwak.monitoring.v0.ListAlertingChannelsForEdgeClusterResponse\x12\xa3\x01\n\"ListAlertingChannelsForCoreCluster\x12=.qwak.monitoring.v0.ListAlertingChannelsForCoreClusterRequest\x1a>.qwak.monitoring.v0.ListAlertingChannelsForCoreClusterResponseB2\n\x1d\x63om.qwak.ai.monitoring.api.v0P\x01Z\x0f.;monitoring_v0b\x06proto3')



_LISTALERTINGCHANNELSFOREDGECLUSTERREQUEST = DESCRIPTOR.message_types_by_name['ListAlertingChannelsForEdgeClusterRequest']
_LISTALERTINGCHANNELSFOREDGECLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['ListAlertingChannelsForEdgeClusterResponse']
_LISTALERTINGCHANNELSFORCORECLUSTERREQUEST = DESCRIPTOR.message_types_by_name['ListAlertingChannelsForCoreClusterRequest']
_LISTALERTINGCHANNELSFORCORECLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['ListAlertingChannelsForCoreClusterResponse']
ListAlertingChannelsForEdgeClusterRequest = _reflection.GeneratedProtocolMessageType('ListAlertingChannelsForEdgeClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTINGCHANNELSFOREDGECLUSTERREQUEST,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_sync_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.ListAlertingChannelsForEdgeClusterRequest)
  })
_sym_db.RegisterMessage(ListAlertingChannelsForEdgeClusterRequest)

ListAlertingChannelsForEdgeClusterResponse = _reflection.GeneratedProtocolMessageType('ListAlertingChannelsForEdgeClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTINGCHANNELSFOREDGECLUSTERRESPONSE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_sync_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.ListAlertingChannelsForEdgeClusterResponse)
  })
_sym_db.RegisterMessage(ListAlertingChannelsForEdgeClusterResponse)

ListAlertingChannelsForCoreClusterRequest = _reflection.GeneratedProtocolMessageType('ListAlertingChannelsForCoreClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTINGCHANNELSFORCORECLUSTERREQUEST,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_sync_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.ListAlertingChannelsForCoreClusterRequest)
  })
_sym_db.RegisterMessage(ListAlertingChannelsForCoreClusterRequest)

ListAlertingChannelsForCoreClusterResponse = _reflection.GeneratedProtocolMessageType('ListAlertingChannelsForCoreClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTINGCHANNELSFORCORECLUSTERRESPONSE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_sync_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.ListAlertingChannelsForCoreClusterResponse)
  })
_sym_db.RegisterMessage(ListAlertingChannelsForCoreClusterResponse)

_ALERTINGCHANNELSYNCSERVICE = DESCRIPTOR.services_by_name['AlertingChannelSyncService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.monitoring.api.v0P\001Z\017.;monitoring_v0'
  _LISTALERTINGCHANNELSFOREDGECLUSTERREQUEST._serialized_start=154
  _LISTALERTINGCHANNELSFOREDGECLUSTERREQUEST._serialized_end=254
  _LISTALERTINGCHANNELSFOREDGECLUSTERRESPONSE._serialized_start=256
  _LISTALERTINGCHANNELSFOREDGECLUSTERRESPONSE._serialized_end=357
  _LISTALERTINGCHANNELSFORCORECLUSTERREQUEST._serialized_start=359
  _LISTALERTINGCHANNELSFORCORECLUSTERREQUEST._serialized_end=459
  _LISTALERTINGCHANNELSFORCORECLUSTERRESPONSE._serialized_start=461
  _LISTALERTINGCHANNELSFORCORECLUSTERRESPONSE._serialized_end=562
  _ALERTINGCHANNELSYNCSERVICE._serialized_start=565
  _ALERTINGCHANNELSYNCSERVICE._serialized_end=925
# @@protoc_insertion_point(module_scope)



import importlib.util
from inspect import signature
from typing import Any, Callable, Dict, Optional

from qwak.exceptions import QwakException
from qwak.feature_store._common.value import (
    UPDATE_QWAK_SDK_WITH_FEATURE_STORE_EXTRA_MSG,
)


def validate_qwargs(qwargs: Dict[Any, Any]):
    for k, v in qwargs.items():
        if not isinstance(k, str) or not isinstance(v, str):
            raise QwakException("Only strings are supported in qwargs entries!")


def validate_function(
    function: Optional[Callable], dataframe_type: type, caller_class: type
):
    """
    Validates a transformation function for a given caller class.

    Parameters
    ----------
    function : Optional[Callable]
        The transformation function to be validated. It should have specific type annotations for its parameters and return type.
    dataframe_type : type
        The dataframe type that the dictionary should accept as value
    caller_class : type
        The class that is calling this validation function. Used for generating error messages.

    Raises
    ------
    QwakException
        If the 'pyspark' dependency is missing.
        If the function is empty.
        If the first argument of the function does not have `Dict[str, pyspark.sql.DataFrame]` type annotation.
        If the second argument of the function is present but not named `qwargs` or does not have `Dict[str, str]` type annotation.
        If the function's return type annotation is not `pyspark.sql.DataFrame`.
    """
    if importlib.util.find_spec("pyspark") is None:
        raise QwakException(
            f"Missing 'pyspark' dependency required for {caller_class.__name__} transformation. "
            f"{UPDATE_QWAK_SDK_WITH_FEATURE_STORE_EXTRA_MSG}"
        )
    if not function:
        raise QwakException(
            f"Please provide a valid function for the {caller_class.__name__} transformation"
        )

    function_signature = signature(function)
    function_parameters = function_signature.parameters

    if (
        len(function_parameters) == 0
        or list(function_parameters.values())[0].annotation != Dict[str, dataframe_type]
    ):
        raise QwakException(
            f"The first argument of a {caller_class.__name__} transformation function must have Dict[str, ${dataframe_type}] type annotation"
        )
    elif len(function_parameters) == 2:
        second_argument = list(function_parameters.values())[1]
        if (
            second_argument.name != "qwargs"
            or second_argument.annotation != Dict[str, Any]
        ):
            raise QwakException(
                f"The second argument of a {caller_class.__name__} transformation function must be named qwargs and have "
                "`Dict[str, Any]` type annotation."
            )
    elif len(function_parameters) > 2:
        raise QwakException(
            f"{caller_class.__name__} transformation function must have at most 2 arguments."
        )
    if function_signature.return_annotation != dataframe_type:
        raise QwakException(
            f"{caller_class.__name__} transformation function must ${dataframe_type} return type annotation."
        )



import os

from .account import UserAccountConfiguration
from .containers import QwakContainer


def wire_dependencies():
    container = QwakContainer()

    default_config_file = os.path.join(os.path.dirname(__file__), "config.yml")
    container.config.from_yaml(default_config_file)

    from qwak.clients import (
        administration,
        alert_management,
        alerts_registry,
        analytics,
        audience,
        automation_management,
        autoscaling,
        batch_job_management,
        build_management,
        build_orchestrator,
        data_versioning,
        deployment,
        feature_store,
        file_versioning,
        instance_template,
        integration_management,
        kube_deployment_captain,
        logging_client,
        model_management,
        project,
        prompt_manager,
        system_secret,
        user_application_instance,
        vector_store,
        workspace_manager,
    )

    container.wire(
        packages=[
            administration,
            alert_management,
            audience,
            automation_management,
            autoscaling,
            analytics,
            batch_job_management,
            build_management,
            build_orchestrator,
            data_versioning,
            deployment,
            file_versioning,
            instance_template,
            kube_deployment_captain,
            logging_client,
            model_management,
            project,
            feature_store,
            user_application_instance,
            alerts_registry,
            workspace_manager,
            vector_store,
            integration_management,
            system_secret,
            prompt_manager,
        ]
    )

    return container



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.logging.log_filter_pb2
import qwak.logging.log_line_pb2
import qwak.logging.log_source_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ReadLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    BEFORE_OFFSET_FIELD_NUMBER: builtins.int
    AFTER_OFFSET_FIELD_NUMBER: builtins.int
    SEARCH_FILTER_FIELD_NUMBER: builtins.int
    MAX_NUMBER_OF_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def source(self) -> qwak.logging.log_source_pb2.LogSource:
        """Source of the logs"""
    before_offset: builtins.str
    """Get logs before offset"""
    after_offset: builtins.str
    """Get logs after offset"""
    @property
    def search_filter(self) -> qwak.logging.log_filter_pb2.SearchFilter:
        """Search filter"""
    max_number_of_results: builtins.int
    """Maximum number of results"""
    def __init__(
        self,
        *,
        source: qwak.logging.log_source_pb2.LogSource | None = ...,
        before_offset: builtins.str = ...,
        after_offset: builtins.str = ...,
        search_filter: qwak.logging.log_filter_pb2.SearchFilter | None = ...,
        max_number_of_results: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["after_offset", b"after_offset", "before_offset", b"before_offset", "offset", b"offset", "search_filter", b"search_filter", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["after_offset", b"after_offset", "before_offset", b"before_offset", "max_number_of_results", b"max_number_of_results", "offset", b"offset", "search_filter", b"search_filter", "source", b"source"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["offset", b"offset"]) -> typing_extensions.Literal["before_offset", "after_offset"] | None: ...

global___ReadLogsRequest = ReadLogsRequest

class ReadLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_LINE_FIELD_NUMBER: builtins.int
    FIRST_OFFSET_FIELD_NUMBER: builtins.int
    LAST_OFFSET_FIELD_NUMBER: builtins.int
    HAS_NEXT_PAGE_FIELD_NUMBER: builtins.int
    @property
    def log_line(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.logging.log_line_pb2.LogLine]:
        """Array of lines"""
    first_offset: builtins.str
    """The first log offset"""
    last_offset: builtins.str
    """The last log offset"""
    has_next_page: builtins.bool
    """Has next page"""
    def __init__(
        self,
        *,
        log_line: collections.abc.Iterable[qwak.logging.log_line_pb2.LogLine] | None = ...,
        first_offset: builtins.str = ...,
        last_offset: builtins.str = ...,
        has_next_page: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["first_offset", b"first_offset", "has_next_page", b"has_next_page", "last_offset", b"last_offset", "log_line", b"log_line"]) -> None: ...

global___ReadLogsResponse = ReadLogsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class OnlineStreamingIngestion(google.protobuf.message.Message):
    """Online Ingestion"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___OnlineStreamingIngestion = OnlineStreamingIngestion

class OfflineStreamingIngestion(google.protobuf.message.Message):
    """Offline Ingestion"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    SCHEDULED_TRIGGER_FIELD_NUMBER: builtins.int
    MANUAL_TRIGGER_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    @property
    def scheduled_trigger(self) -> global___ScheduledOfflineStreamingTrigger: ...
    @property
    def manual_trigger(self) -> global___ManualOfflineStreamingTrigger: ...
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
        scheduled_trigger: global___ScheduledOfflineStreamingTrigger | None = ...,
        manual_trigger: global___ManualOfflineStreamingTrigger | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["manual_trigger", b"manual_trigger", "scheduled_trigger", b"scheduled_trigger", "trigger_type", b"trigger_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name", "manual_trigger", b"manual_trigger", "scheduled_trigger", b"scheduled_trigger", "trigger_type", b"trigger_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["trigger_type", b"trigger_type"]) -> typing_extensions.Literal["scheduled_trigger", "manual_trigger"] | None: ...

global___OfflineStreamingIngestion = OfflineStreamingIngestion

class ScheduledOfflineStreamingTrigger(google.protobuf.message.Message):
    """Scheduled offline ingestion (e.g., AirFlow)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ScheduledOfflineStreamingTrigger = ScheduledOfflineStreamingTrigger

class ManualOfflineStreamingTrigger(google.protobuf.message.Message):
    """Manual Offline ingestion (that is, someone manually running from the UI)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ManualOfflineStreamingTrigger = ManualOfflineStreamingTrigger



from abc import ABC
from typing import Generic, TypeVar

from qwak.llmops.generation.chat.openai.types.chat.chat_completion_chunk import (
    ChatCompletionChunk,
)

try:
    from collections import Iterable

    iterableABC = Iterable
except ImportError:
    from collections.abc import Iterable

    iterableABC = Iterable


_T = TypeVar("_T")


class Stream(Generic[_T], ABC, iterableABC):
    pass


class ChatCompletionStream(Stream[ChatCompletionChunk], ABC):
    pass



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.feature_store.entities.entity_pb2
import qwak.feature_store.features.feature_set_attribute_pb2
import qwak.feature_store.features.feature_set_state_pb2
import qwak.feature_store.features.feature_set_types_pb2
import qwak.feature_store.v1.common.source_code.source_code_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FeatureStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FeatureStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FeatureStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID: _FeatureStatus.ValueType  # 0
    VALID: _FeatureStatus.ValueType  # 1
    DELETED: _FeatureStatus.ValueType  # 2
    REGISTRATION_FAILED: _FeatureStatus.ValueType  # 3
    REGISTRATION_IN_PROGRESS: _FeatureStatus.ValueType  # 4
    DELETION_IN_PROGRESS: _FeatureStatus.ValueType  # 5
    DELETION_FAILED: _FeatureStatus.ValueType  # 6
    BACKFILL_IN_PROGRESS: _FeatureStatus.ValueType  # 7

class FeatureStatus(_FeatureStatus, metaclass=_FeatureStatusEnumTypeWrapper): ...

INVALID: FeatureStatus.ValueType  # 0
VALID: FeatureStatus.ValueType  # 1
DELETED: FeatureStatus.ValueType  # 2
REGISTRATION_FAILED: FeatureStatus.ValueType  # 3
REGISTRATION_IN_PROGRESS: FeatureStatus.ValueType  # 4
DELETION_IN_PROGRESS: FeatureStatus.ValueType  # 5
DELETION_FAILED: FeatureStatus.ValueType  # 6
BACKFILL_IN_PROGRESS: FeatureStatus.ValueType  # 7
global___FeatureStatus = FeatureStatus

class _FeaturesetSchedulingState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FeaturesetSchedulingStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FeaturesetSchedulingState.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SCHEDULING_STATE_INVALID: _FeaturesetSchedulingState.ValueType  # 0
    SCHEDULING_STATE_ENABLED: _FeaturesetSchedulingState.ValueType  # 1
    """This featureset is scheduled"""
    SCHEDULING_STATE_PAUSED: _FeaturesetSchedulingState.ValueType  # 2
    """This featureset is paused"""
    SCHEDULING_STATE_UNKNOWN: _FeaturesetSchedulingState.ValueType  # 3
    """can't determine (e.g., airflow down)"""

class FeaturesetSchedulingState(_FeaturesetSchedulingState, metaclass=_FeaturesetSchedulingStateEnumTypeWrapper):
    """an enum to represent the scheduling state - that is, if it's paused/resumed etc"""

SCHEDULING_STATE_INVALID: FeaturesetSchedulingState.ValueType  # 0
SCHEDULING_STATE_ENABLED: FeaturesetSchedulingState.ValueType  # 1
"""This featureset is scheduled"""
SCHEDULING_STATE_PAUSED: FeaturesetSchedulingState.ValueType  # 2
"""This featureset is paused"""
SCHEDULING_STATE_UNKNOWN: FeaturesetSchedulingState.ValueType  # 3
"""can't determine (e.g., airflow down)"""
global___FeaturesetSchedulingState = FeaturesetSchedulingState

class FeatureSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_DEFINITION_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    DEPLOYED_MODELS_IN_USE_LINK_FIELD_NUMBER: builtins.int
    @property
    def feature_set_definition(self) -> global___FeatureSetDefinition:
        """Complete domain definition of the feature set"""
    @property
    def metadata(self) -> global___FeatureSetMetadata:
        """System generated metadata of the feature set"""
    @property
    def deployed_models_in_use_link(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeployedModelInUseLink]:
        """Deployed models which use this feature set"""
    def __init__(
        self,
        *,
        feature_set_definition: global___FeatureSetDefinition | None = ...,
        metadata: global___FeatureSetMetadata | None = ...,
        deployed_models_in_use_link: collections.abc.Iterable[global___DeployedModelInUseLink] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_definition", b"feature_set_definition", "metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployed_models_in_use_link", b"deployed_models_in_use_link", "feature_set_definition", b"feature_set_definition", "metadata", b"metadata"]) -> None: ...

global___FeatureSet = FeatureSet

class FeaturesetInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_DEFINITION_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def featureset_definition(self) -> global___FeatureSetDefinition:
        """Complete domain definition of the featureset"""
    @property
    def metadata(self) -> global___FeatureSetMetadata:
        """System generated metadata of the featureset"""
    def __init__(
        self,
        *,
        featureset_definition: global___FeatureSetDefinition | None = ...,
        metadata: global___FeatureSetMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["featureset_definition", b"featureset_definition", "metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_definition", b"featureset_definition", "metadata", b"metadata"]) -> None: ...

global___FeaturesetInfo = FeaturesetInfo

class FeaturesetSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FEATURE_SET_TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique id"""
    name: builtins.str
    """Name of feature set"""
    @property
    def feature_set_type(self) -> qwak.feature_store.features.feature_set_types_pb2.FeatureSetType:
        """Type of feature set"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        feature_set_type: qwak.feature_store.features.feature_set_types_pb2.FeatureSetType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_type", b"feature_set_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_type", b"feature_set_type", "id", b"id", "name", b"name"]) -> None: ...

global___FeaturesetSummary = FeaturesetSummary

class FeatureSetDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    FEATURE_SET_SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    FEATURE_SET_LAST_EXECUTION_STATE_FIELD_NUMBER: builtins.int
    FEATURE_HEALTH_FIELD_NUMBER: builtins.int
    FEATURE_SET_STATE_FIELD_NUMBER: builtins.int
    QWAK_INTERNAL_PROTOCOL_VERSION_FIELD_NUMBER: builtins.int
    FEATURESET_VERSION_NUMBER_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    """Assigned unique id"""
    @property
    def feature_set_spec(self) -> global___FeatureSetSpec:
        """Specifications of the feature set"""
    status: global___FeatureStatus.ValueType
    """Feature Status"""
    feature_set_last_execution_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetLastExecutionState.ValueType
    """Feature set airflow state"""
    feature_health: qwak.feature_store.features.feature_set_state_pb2.FeatureSetLastExecutionState.ValueType
    """Feature set Health"""
    @property
    def feature_set_state(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.features.feature_set_state_pb2.FeatureSetState]:
        """The state of the feature set"""
    qwak_internal_protocol_version: builtins.int
    """Qwak featureset version"""
    featureset_version_number: builtins.int
    """Featureset Version number"""
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
        feature_set_spec: global___FeatureSetSpec | None = ...,
        status: global___FeatureStatus.ValueType = ...,
        feature_set_last_execution_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetLastExecutionState.ValueType = ...,
        feature_health: qwak.feature_store.features.feature_set_state_pb2.FeatureSetLastExecutionState.ValueType = ...,
        feature_set_state: collections.abc.Iterable[qwak.feature_store.features.feature_set_state_pb2.FeatureSetState] | None = ...,
        qwak_internal_protocol_version: builtins.int = ...,
        featureset_version_number: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_spec", b"feature_set_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_health", b"feature_health", "feature_set_id", b"feature_set_id", "feature_set_last_execution_state", b"feature_set_last_execution_state", "feature_set_spec", b"feature_set_spec", "feature_set_state", b"feature_set_state", "featureset_version_number", b"featureset_version_number", "qwak_internal_protocol_version", b"qwak_internal_protocol_version", "status", b"status"]) -> None: ...

global___FeatureSetDefinition = FeatureSetDefinition

class FeatureSetSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    GIT_COMMIT_FIELD_NUMBER: builtins.int
    ENTITY_FIELD_NUMBER: builtins.int
    FEATURE_SET_TYPE_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    QWAK_INTERNAL_PROTOCOL_VERSION_FIELD_NUMBER: builtins.int
    SOURCE_CODE_SPEC_FIELD_NUMBER: builtins.int
    FEATURESET_ATTRIBUTES_FIELD_NUMBER: builtins.int
    FEATURESET_REPOSITORY_NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of feature"""
    @property
    def metadata(self) -> global___FeatureSetUserMetadata:
        """User generated metadata of the feature set"""
    git_commit: builtins.str
    """Git commit which the feature is based on"""
    @property
    def entity(self) -> qwak.feature_store.entities.entity_pb2.EntityDefinition:
        """Entity specification used by the feature"""
    @property
    def feature_set_type(self) -> qwak.feature_store.features.feature_set_types_pb2.FeatureSetType:
        """Feature set - actual implementation of the feature"""
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Feature]:
        """List of features in the registration"""
    qwak_internal_protocol_version: builtins.int
    """Qwak featureset version"""
    @property
    def source_code_spec(self) -> qwak.feature_store.v1.common.source_code.source_code_pb2.SourceCodeSpec: ...
    @property
    def featureset_attributes(self) -> qwak.feature_store.features.feature_set_attribute_pb2.FeaturesetAttributes:
        """Featureset attributes"""
    featureset_repository_name: builtins.str
    """Featureset repository name"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        metadata: global___FeatureSetUserMetadata | None = ...,
        git_commit: builtins.str = ...,
        entity: qwak.feature_store.entities.entity_pb2.EntityDefinition | None = ...,
        feature_set_type: qwak.feature_store.features.feature_set_types_pb2.FeatureSetType | None = ...,
        features: collections.abc.Iterable[global___Feature] | None = ...,
        qwak_internal_protocol_version: builtins.int = ...,
        source_code_spec: qwak.feature_store.v1.common.source_code.source_code_pb2.SourceCodeSpec | None = ...,
        featureset_attributes: qwak.feature_store.features.feature_set_attribute_pb2.FeaturesetAttributes | None = ...,
        featureset_repository_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity", "feature_set_type", b"feature_set_type", "featureset_attributes", b"featureset_attributes", "featureset_repository_identifier", b"featureset_repository_identifier", "featureset_repository_name", b"featureset_repository_name", "metadata", b"metadata", "source_code_spec", b"source_code_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity", "feature_set_type", b"feature_set_type", "features", b"features", "featureset_attributes", b"featureset_attributes", "featureset_repository_identifier", b"featureset_repository_identifier", "featureset_repository_name", b"featureset_repository_name", "git_commit", b"git_commit", "metadata", b"metadata", "name", b"name", "qwak_internal_protocol_version", b"qwak_internal_protocol_version", "source_code_spec", b"source_code_spec"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["featureset_repository_identifier", b"featureset_repository_identifier"]) -> typing_extensions.Literal["featureset_repository_name"] | None: ...

global___FeatureSetSpec = FeatureSetSpec

class FeatureSetUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    FEATURESET_VERSION_USER_METADATA_FIELD_NUMBER: builtins.int
    owner: builtins.str
    """Feature set owner"""
    description: builtins.str
    """Human readable description of the feature set"""
    display_name: builtins.str
    """User friendly name of the feature set"""
    @property
    def featureset_version_user_metadata(self) -> global___FeaturesetVersionUserMetadata:
        """User generated metadata of the featureset version"""
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        featureset_version_user_metadata: global___FeaturesetVersionUserMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["featureset_version_user_metadata", b"featureset_version_user_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_name", b"display_name", "featureset_version_user_metadata", b"featureset_version_user_metadata", "owner", b"owner"]) -> None: ...

global___FeatureSetUserMetadata = FeatureSetUserMetadata

class FeaturesetVersionUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMENT_FIELD_NUMBER: builtins.int
    comment: builtins.str
    """Human-readable comment for the featureset version"""
    def __init__(
        self,
        *,
        comment: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment", b"comment"]) -> None: ...

global___FeaturesetVersionUserMetadata = FeaturesetVersionUserMetadata

class FeatureSetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    FEATURESET_VERSION_METADATA_FIELD_NUMBER: builtins.int
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the feature set was created"""
    created_by: builtins.str
    """Created by"""
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last modified"""
    last_modified_by: builtins.str
    """Last modified by"""
    @property
    def featureset_version_metadata(self) -> global___FeaturesetVersionMetadata:
        """Featureset version metadata"""
    def __init__(
        self,
        *,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_by: builtins.str = ...,
        featureset_version_metadata: global___FeaturesetVersionMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "featureset_version_metadata", b"featureset_version_metadata", "last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by", "featureset_version_metadata", b"featureset_version_metadata", "last_modified_at", b"last_modified_at", "last_modified_by", b"last_modified_by"]) -> None: ...

global___FeatureSetMetadata = FeatureSetMetadata

class FeaturesetVersionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the featureset version was created"""
    created_by: builtins.str
    """Featureset version created by"""
    def __init__(
        self,
        *,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by"]) -> None: ...

global___FeaturesetVersionMetadata = FeaturesetVersionMetadata

class DeployedModelInUseLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    MODEL_NAME_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """Model Id of a model which is using the Feature Set"""
    model_name: builtins.str
    """Model Name of a model which is using the Feature Set"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        model_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_id", b"model_id", "model_name", b"model_name"]) -> None: ...

global___DeployedModelInUseLink = DeployedModelInUseLink

class Feature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_NAME_FIELD_NUMBER: builtins.int
    FEATURE_TYPE_FIELD_NUMBER: builtins.int
    feature_name: builtins.str
    """Feature Name"""
    feature_type: builtins.str
    """Feature Spark Type"""
    def __init__(
        self,
        *,
        feature_name: builtins.str = ...,
        feature_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_name", b"feature_name", "feature_type", b"feature_type"]) -> None: ...

global___Feature = Feature

class DeployedFeatureSetSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_SPEC_FIELD_NUMBER: builtins.int
    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    FEATURESET_VERSION_FIELD_NUMBER: builtins.int
    @property
    def feature_set_spec(self) -> global___FeatureSetSpec:
        """Feature set spec"""
    feature_set_id: builtins.str
    """Feature set Id"""
    account_id: builtins.str
    """Account id"""
    featureset_version: builtins.int
    """Featureset version"""
    def __init__(
        self,
        *,
        feature_set_spec: global___FeatureSetSpec | None = ...,
        feature_set_id: builtins.str = ...,
        account_id: builtins.str = ...,
        featureset_version: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_spec", b"feature_set_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "feature_set_id", b"feature_set_id", "feature_set_spec", b"feature_set_spec", "featureset_version", b"featureset_version"]) -> None: ...

global___DeployedFeatureSetSpec = DeployedFeatureSetSpec

class FeatureSetList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SETS_FIELD_NUMBER: builtins.int
    @property
    def feature_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeatureSet]: ...
    def __init__(
        self,
        *,
        feature_sets: collections.abc.Iterable[global___FeatureSet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_sets", b"feature_sets"]) -> None: ...

global___FeatureSetList = FeatureSetList



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.administration.v0.users.user_pb2
import qwak.self_service.account.v0.account_membership_pb2
import qwak.self_service.user.v1.user_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ListAccountUserProfilesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAccountUserProfilesRequest = ListAccountUserProfilesRequest

class ListAccountUserProfilesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_PROFILES_FIELD_NUMBER: builtins.int
    @property
    def user_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.user.v1.user_pb2.UserProfile]:
        """All account users"""
    def __init__(
        self,
        *,
        user_profiles: collections.abc.Iterable[qwak.self_service.user.v1.user_pb2.UserProfile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_profiles", b"user_profiles"]) -> None: ...

global___ListAccountUserProfilesResponse = ListAccountUserProfilesResponse

class UpdateUserRoleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ROLE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """User ID"""
    account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType
    """User account role"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_role", b"account_role", "id", b"id"]) -> None: ...

global___UpdateUserRoleRequest = UpdateUserRoleRequest

class UpdateUserRoleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def user_profile(self) -> qwak.self_service.user.v1.user_pb2.UserProfile:
        """All account users"""
    def __init__(
        self,
        *,
        user_profile: qwak.self_service.user.v1.user_pb2.UserProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user_profile", b"user_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_profile", b"user_profile"]) -> None: ...

global___UpdateUserRoleResponse = UpdateUserRoleResponse

class UpdateUserAssignedEnvironmentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_IDS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """User ID"""
    @property
    def environment_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User bound environments"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        environment_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_ids", b"environment_ids", "id", b"id"]) -> None: ...

global___UpdateUserAssignedEnvironmentsRequest = UpdateUserAssignedEnvironmentsRequest

class UpdateUserAssignedEnvironmentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def user_profile(self) -> qwak.self_service.user.v1.user_pb2.UserProfile:
        """All account users"""
    def __init__(
        self,
        *,
        user_profile: qwak.self_service.user.v1.user_pb2.UserProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user_profile", b"user_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_profile", b"user_profile"]) -> None: ...

global___UpdateUserAssignedEnvironmentsResponse = UpdateUserAssignedEnvironmentsResponse

class RemoveUserFromAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """User ID"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___RemoveUserFromAccountRequest = RemoveUserFromAccountRequest

class RemoveUserFromAccountResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RemoveUserFromAccountResponse = RemoveUserFromAccountResponse

class InviteToJoinAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.account_membership_pb2.InviteOptions]:
        """Options for new invitations"""
    def __init__(
        self,
        *,
        options: collections.abc.Iterable[qwak.self_service.account.v0.account_membership_pb2.InviteOptions] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___InviteToJoinAccountRequest = InviteToJoinAccountRequest

class InviteToJoinAccountResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATIONS_FIELD_NUMBER: builtins.int
    @property
    def invitations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription]: ...
    def __init__(
        self,
        *,
        invitations: collections.abc.Iterable[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitations", b"invitations"]) -> None: ...

global___InviteToJoinAccountResponse = InviteToJoinAccountResponse

class UpdateInvitationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATION_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ROLE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_IDS_FIELD_NUMBER: builtins.int
    invitation_id: builtins.str
    """Id of the invitation"""
    account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType
    """User account role"""
    @property
    def environment_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Bind user to environments"""
    def __init__(
        self,
        *,
        invitation_id: builtins.str = ...,
        account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType = ...,
        environment_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_role", b"account_role", "environment_ids", b"environment_ids", "invitation_id", b"invitation_id"]) -> None: ...

global___UpdateInvitationRequest = UpdateInvitationRequest

class UpdateInvitationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATION_FIELD_NUMBER: builtins.int
    @property
    def invitation(self) -> qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription: ...
    def __init__(
        self,
        *,
        invitation: qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["invitation", b"invitation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitation", b"invitation"]) -> None: ...

global___UpdateInvitationResponse = UpdateInvitationResponse

class AcceptInvitationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATION_ID_FIELD_NUMBER: builtins.int
    invitation_id: builtins.str
    """Id of the invitation"""
    def __init__(
        self,
        *,
        invitation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitation_id", b"invitation_id"]) -> None: ...

global___AcceptInvitationRequest = AcceptInvitationRequest

class AcceptInvitationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AcceptInvitationResponse = AcceptInvitationResponse

class CancelJoiningInvitationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATION_ID_FIELD_NUMBER: builtins.int
    invitation_id: builtins.str
    """Id of the invitation"""
    def __init__(
        self,
        *,
        invitation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitation_id", b"invitation_id"]) -> None: ...

global___CancelJoiningInvitationRequest = CancelJoiningInvitationRequest

class CancelJoiningInvitationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CancelJoiningInvitationResponse = CancelJoiningInvitationResponse

class ListAccountInvitationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAccountInvitationsRequest = ListAccountInvitationsRequest

class ListAccountInvitationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATIONS_FIELD_NUMBER: builtins.int
    @property
    def invitations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription]: ...
    def __init__(
        self,
        *,
        invitations: collections.abc.Iterable[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitations", b"invitations"]) -> None: ...

global___ListAccountInvitationsResponse = ListAccountInvitationsResponse

class ListUserInvitationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListUserInvitationsRequest = ListUserInvitationsRequest

class ListUserInvitationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATIONS_FIELD_NUMBER: builtins.int
    @property
    def invitations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription]: ...
    def __init__(
        self,
        *,
        invitations: collections.abc.Iterable[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitations", b"invitations"]) -> None: ...

global___ListUserInvitationsResponse = ListUserInvitationsResponse

class ListUserMembershipsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListUserMembershipsRequest = ListUserMembershipsRequest

class ListUserMembershipsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ACCOUNTS_FIELD_NUMBER: builtins.int
    INVITATIONS_FIELD_NUMBER: builtins.int
    @property
    def user_accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.account_membership_pb2.UserAccountDescription]: ...
    @property
    def invitations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription]: ...
    def __init__(
        self,
        *,
        user_accounts: collections.abc.Iterable[qwak.self_service.account.v0.account_membership_pb2.UserAccountDescription] | None = ...,
        invitations: collections.abc.Iterable[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitations", b"invitations", "user_accounts", b"user_accounts"]) -> None: ...

global___ListUserMembershipsResponse = ListUserMembershipsResponse



from dataclasses import dataclass
from typing import Optional

from _qwak_proto.qwak.feature_store.sources.batch_pb2 import (
    BatchSource as ProtoBatchSource,
    ClickhouseSource as ProtoClickhouseSource,
)
from _qwak_proto.qwak.feature_store.sources.data_source_pb2 import (
    DataSourceSpec as ProtoDataSourceSpec,
)
from qwak.exceptions import QwakException
from qwak.feature_store.data_sources.batch._batch import BaseBatchSource


@dataclass
class ClickhouseSource(BaseBatchSource):
    username_secret_name: Optional[str] = None
    password_secret_name: Optional[str] = None
    url: Optional[str] = None
    db_table: Optional[str] = None
    query: Optional[str] = None

    def __post_init__(self):
        self._validate()

    def _validate(self):
        if not (bool(self.db_table) ^ bool(self.query)):
            raise QwakException("Only one of query and db_table must be set")

    def _to_proto(self, artifact_url: Optional[str] = None):
        return ProtoDataSourceSpec(
            batch_source=ProtoBatchSource(
                name=self.name,
                description=self.description,
                date_created_column=self.date_created_column,
                clickhouseSource=ProtoClickhouseSource(
                    url=self.url,
                    username_secret_name=self.username_secret_name,
                    password_secret_name=self.password_secret_name,
                    table=self.db_table,
                    sql=self.query,
                ),
            )
        )

    @classmethod
    def _from_proto(cls, proto: ProtoBatchSource):
        clickhouse: ProtoClickhouseSource = proto.clickhouseSource
        return cls(
            name=proto.name,
            date_created_column=proto.date_created_column,
            description=proto.description,
            url=clickhouse.url,
            username_secret_name=clickhouse.username_secret_name,
            password_secret_name=clickhouse.password_secret_name,
            db_table=clickhouse.table,
            query=clickhouse.sql,
        )



from typing import List, Optional

from _qwak_proto.qwak.model_descriptor.open_ai_descriptor_pb2 import (
    OpenAIModelDescriptor as ProtoOpenAIModelDescriptor,
)
from _qwak_proto.qwak.prompt.v1.prompt.prompt_pb2 import (
    AIPromptMessageRole as ProtoAIPromptMessageRole,
    ChatMessage as ProtoChatMessage,
    ChatMessageTemplate as ProtoChatMessageTemplate,
    ChatPromptTemplate as ProtoChatPromptTemplate,
    HumanPromptMessageRole as ProtoHumanPromptMessageRole,
    PromptMessageRole as ProtoPromptMessageRole,
    PromptModelDescriptor as ProtoPromptModelDescriptor,
    PromptOpenAIProvider as ProtoPromptOpenAIProvider,
    PromptTemplate as ProtoPromptTemplate,
    PromptVersionDefinition as ProtoPromptVersionDefinition,
    PromptVersionSpec as ProtoPromptVersionSpec,
    SystemPromptMessageRole as ProtoSystemPromptMessageRole,
    TextTemplate as ProtoTextTemplate,
)
from qwak.clients.prompt_manager.model_descriptor_mapper import ModelDescriptorMapper
from qwak.exceptions import QwakException
from qwak.llmops.model.descriptor import ChatModelDescriptor, ModelDescriptor
from qwak.llmops.prompt.base import BasePrompt, ChatPrompt, RegisteredPrompt
from qwak.llmops.prompt.chat.message import (
    AIMessage,
    BaseMessage,
    HumanMessage,
    SystemMessage,
)
from qwak.llmops.prompt.chat.template import (
    AIMessagePromptTemplate,
    BaseStringMessagePromptTemplate,
    ChatPromptTemplate,
    HumanMessagePromptTemplate,
    SystemMessagePromptTemplate,
)
from qwak.llmops.prompt.template import BasePromptTemplate


class PromptProtoMapper:
    @staticmethod
    def from_chat_prompt_template(
        chat_prompt_template: ProtoChatPromptTemplate,
    ) -> ChatPromptTemplate:
        messages: List[BaseStringMessagePromptTemplate] = []
        for chat_message in chat_prompt_template.chat_messages:
            template: str = chat_message.template.text_template.template
            role_type: str = chat_message.role.WhichOneof("role")
            if role_type == "human_role":
                messages.append(HumanMessagePromptTemplate(template=template))
            elif role_type == "system_role":
                messages.append(SystemMessagePromptTemplate(template=template))
            elif role_type == "ai_role":
                messages.append(AIMessagePromptTemplate(template=template))
            else:
                raise QwakException(
                    f"Got unsupported chat message type: {repr(chat_message)}"
                )

        return ChatPromptTemplate(messages=messages)

    @staticmethod
    def from_prompt_template(
        prompt_template: ProtoPromptTemplate,
    ) -> BasePromptTemplate:
        if prompt_template.WhichOneof("type") == "chat_prompt_template":
            return PromptProtoMapper.from_chat_prompt_template(
                chat_prompt_template=prompt_template.chat_prompt_template
            )
        else:
            raise QwakException(
                f"Got unsupported prompt template: {repr(prompt_template)}"
            )

    @staticmethod
    def to_prompt_model_descriptor(
        model_descriptor: ModelDescriptor,
    ) -> ProtoPromptModelDescriptor:
        proto_model_descriptor = ModelDescriptorMapper.to_model_descriptor(
            model_descriptor=model_descriptor
        )
        if isinstance(proto_model_descriptor, ProtoOpenAIModelDescriptor):
            return ProtoPromptModelDescriptor(
                open_ai_provider=ProtoPromptOpenAIProvider(
                    open_ai_model_descriptor=proto_model_descriptor
                )
            )

        raise QwakException(
            f"Got unsupported model descriptor: {repr(model_descriptor)}"
        )

    @staticmethod
    def _prompt_template_to_chat_message(
        msg: BaseStringMessagePromptTemplate,
    ) -> ProtoChatMessage:
        role: ProtoPromptMessageRole
        text_template: str = msg.template.template

        if isinstance(msg, SystemMessagePromptTemplate):
            role = ProtoPromptMessageRole(system_role=ProtoSystemPromptMessageRole())
        elif isinstance(msg, HumanMessagePromptTemplate):
            role = ProtoPromptMessageRole(human_role=ProtoHumanPromptMessageRole())
        elif isinstance(msg, AIMessagePromptTemplate):
            role = ProtoPromptMessageRole(ai_role=ProtoAIPromptMessageRole())
        else:
            raise QwakException(f"Got unsupported prompt template role: {repr(msg)}")

        return ProtoChatMessage(
            role=role,
            template=ProtoChatMessageTemplate(
                text_template=ProtoTextTemplate(template=text_template)
            ),
        )

    @staticmethod
    def _base_message_to_chat_message(msg: BaseMessage) -> ProtoChatMessage:
        role: ProtoPromptMessageRole
        text_template: str = msg.content

        if isinstance(msg, AIMessage):
            role = ProtoPromptMessageRole(ai_role=ProtoAIPromptMessageRole())
        elif isinstance(msg, HumanMessage):
            role = ProtoPromptMessageRole(human_role=ProtoHumanPromptMessageRole())
        elif isinstance(msg, SystemMessage):
            role = ProtoPromptMessageRole(system_role=ProtoSystemPromptMessageRole())
        else:
            raise QwakException(f"Got unsupported prompt template role: {repr(msg)}")

        return ProtoChatMessage(
            role=role,
            template=ProtoChatMessageTemplate(
                text_template=ProtoTextTemplate(template=text_template)
            ),
        )

    @staticmethod
    def to_proto_chat_prompt_template(
        prompt_template: ChatPromptTemplate,
    ) -> ProtoPromptTemplate:
        chat_messages: List[ProtoChatMessage] = []

        for msg in prompt_template.messages:
            if isinstance(msg, BaseStringMessagePromptTemplate):
                chat_messages.append(
                    PromptProtoMapper._prompt_template_to_chat_message(msg=msg)
                )
            elif isinstance(msg, BaseMessage):
                chat_messages.append(
                    PromptProtoMapper._base_message_to_chat_message(msg=msg)
                )

        return ProtoPromptTemplate(
            chat_prompt_template=ProtoChatPromptTemplate(chat_messages=chat_messages)
        )

    @staticmethod
    def to_proto_prompt_template(
        prompt_template: BasePromptTemplate,
    ) -> ProtoPromptTemplate:
        if isinstance(prompt_template, ChatPromptTemplate):
            return PromptProtoMapper.to_proto_chat_prompt_template(
                prompt_template=prompt_template
            )

        raise QwakException(f"Got unsupported prompt template: {repr(prompt_template)}")

    @staticmethod
    def to_prompt_version_spec(
        version_description: str,
        prompt_template: BasePromptTemplate,
        model_descriptor: Optional[ModelDescriptor],
    ) -> ProtoPromptVersionSpec:
        prompt_model_descriptor: Optional[ProtoPromptModelDescriptor] = None

        if model_descriptor:
            prompt_model_descriptor: ProtoPromptModelDescriptor = (
                PromptProtoMapper.to_prompt_model_descriptor(
                    model_descriptor=model_descriptor
                )
            )

        proto_prompt_template: ProtoPromptTemplate = (
            PromptProtoMapper.to_proto_prompt_template(prompt_template=prompt_template)
        )

        return ProtoPromptVersionSpec(
            description=version_description,
            prompt_template=proto_prompt_template,
            model_descriptor=prompt_model_descriptor,
        )

    @staticmethod
    def from_prompt_version_definition(
        prompt_version_def: ProtoPromptVersionDefinition,
    ) -> BasePrompt:
        model_descriptor: Optional[ModelDescriptor] = None
        prompt_template: ProtoPromptTemplate = (
            prompt_version_def.version_spec.prompt_template
        )
        base_prompt_template: BasePromptTemplate = (
            PromptProtoMapper.from_prompt_template(prompt_template)
        )

        if prompt_version_def.version_spec.HasField("model_descriptor"):
            model_descriptor: ModelDescriptor = (
                ModelDescriptorMapper.from_prompt_model_descriptor(
                    model_descriptor=prompt_version_def.version_spec.model_descriptor
                )
            )

        if isinstance(base_prompt_template, ChatPromptTemplate) and (
            not model_descriptor or isinstance(model_descriptor, ChatModelDescriptor)
        ):
            return ChatPrompt(template=base_prompt_template, model=model_descriptor)

    @staticmethod
    def from_prompt(
        name: str,
        prompt_description: str,
        version_description: str,
        version: int,
        target_default_version: bool,
        prompt_version_definition: ProtoPromptVersionDefinition,
    ) -> RegisteredPrompt:
        return RegisteredPrompt(
            name=name,
            prompt_description=prompt_description,
            version_description=version_description,
            version=version,
            _target_default_version=target_default_version,
            prompt=PromptProtoMapper.from_prompt_version_definition(
                prompt_version_def=prompt_version_definition
            ),
        )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.feature_store.v1.common.source_code.source_code_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FeaturesetAttributes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_CODE_SPEC_FIELD_NUMBER: builtins.int
    @property
    def source_code_spec(self) -> qwak.feature_store.v1.common.source_code.source_code_pb2.SourceCodeSpec:
        """Featureset source code"""
    def __init__(
        self,
        *,
        source_code_spec: qwak.feature_store.v1.common.source_code.source_code_pb2.SourceCodeSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_code_spec", b"source_code_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_code_spec", b"source_code_spec"]) -> None: ...

global___FeaturesetAttributes = FeaturesetAttributes



import grpc
from _qwak_proto.qwak.feature_store.features.feature_set_state_pb2 import (
    FeatureSetState,
)
from _qwak_proto.qwak.feature_store.features.feature_set_state_service_pb2 import (
    GetFeatureSetStateByIdV1Response,
    GetFeatureSetStateByNameV1Response,
)
from _qwak_proto.qwak.feature_store.features.feature_set_state_service_pb2_grpc import (
    FeatureSetStateServiceServicer,
)
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class FeaturesSetStateServiceApiMock(FeatureSetStateServiceServicer):
    def __init__(self):
        self._feature_state_states: dict[(str, str):FeatureSetState] = {}
        super(FeaturesSetStateServiceApiMock, self).__init__()

    def given_feature_set_state(self, feature_set_state: FeatureSetState):
        self._feature_state_states[
            (feature_set_state.feature_set_id, feature_set_state.run_id)
        ] = feature_set_state

    def GetFeatureSetStateById(self, request, context):
        """get feature set state by id"""
        try:
            return GetFeatureSetStateByIdV1Response(
                feature_set_state=self._feature_state_states[
                    (request.feature_set_id, request.run_id)
                ]
            )
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def GetFeatureSetStateByName(self, request, context):
        """get feature set state by name"""
        try:
            feature_sets_by_name = [
                self._feature_state_states[(feature_set_id, run_id)]
                for feature_set_id, run_id in self._feature_state_states.keys()
                if self._feature_state_states[(feature_set_id, run_id)].feature_set_name
                == request.feature_set_name
            ]
            if len(feature_sets_by_name) > 0:
                return GetFeatureSetStateByNameV1Response(
                    feature_set_state=feature_sets_by_name.pop()
                )
            else:
                context.set_code(grpc.StatusCode.NOT_FOUND)
                context.set_details("Received a non existing feature set name")
                return GetFeatureSetStateByNameV1Response()
        except Exception as e:
            raise_internal_grpc_error(context, e)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/kube_deployment_captain/alerting.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/kube_deployment_captain/alerting.proto\x12\x1cqwak.kube.deployment.captain\"3\n\x07\x43hannel\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"f\n\x13\x46\x65\x61tureSetAlertType\x12G\n\x07\x66\x61ilure\x18\x01 \x01(\x0b\x32\x34.qwak.kube.deployment.captain.FeatureSetFailureAlertH\x00\x42\x06\n\x04type\"Q\n\x16\x46\x65\x61tureSetFailureAlert\x12\x37\n\x08\x63hannels\x18\x01 \x03(\x0b\x32%.qwak.kube.deployment.captain.Channel\"\xbc\x01\n\x16\x46\x65\x61tureSetAlertOptions\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x03 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\x12\x46\n\x0b\x61lert_types\x18\x05 \x03(\x0b\x32\x31.qwak.kube.deployment.captain.FeatureSetAlertTypeB+\n\'com.qwak.ai.kube.deployment.captain.apiP\x01\x62\x06proto3')



_CHANNEL = DESCRIPTOR.message_types_by_name['Channel']
_FEATURESETALERTTYPE = DESCRIPTOR.message_types_by_name['FeatureSetAlertType']
_FEATURESETFAILUREALERT = DESCRIPTOR.message_types_by_name['FeatureSetFailureAlert']
_FEATURESETALERTOPTIONS = DESCRIPTOR.message_types_by_name['FeatureSetAlertOptions']
Channel = _reflection.GeneratedProtocolMessageType('Channel', (_message.Message,), {
  'DESCRIPTOR' : _CHANNEL,
  '__module__' : 'qwak.kube_deployment_captain.alerting_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.Channel)
  })
_sym_db.RegisterMessage(Channel)

FeatureSetAlertType = _reflection.GeneratedProtocolMessageType('FeatureSetAlertType', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETALERTTYPE,
  '__module__' : 'qwak.kube_deployment_captain.alerting_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.FeatureSetAlertType)
  })
_sym_db.RegisterMessage(FeatureSetAlertType)

FeatureSetFailureAlert = _reflection.GeneratedProtocolMessageType('FeatureSetFailureAlert', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETFAILUREALERT,
  '__module__' : 'qwak.kube_deployment_captain.alerting_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.FeatureSetFailureAlert)
  })
_sym_db.RegisterMessage(FeatureSetFailureAlert)

FeatureSetAlertOptions = _reflection.GeneratedProtocolMessageType('FeatureSetAlertOptions', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETALERTOPTIONS,
  '__module__' : 'qwak.kube_deployment_captain.alerting_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.FeatureSetAlertOptions)
  })
_sym_db.RegisterMessage(FeatureSetAlertOptions)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.qwak.ai.kube.deployment.captain.apiP\001'
  _CHANNEL._serialized_start=77
  _CHANNEL._serialized_end=128
  _FEATURESETALERTTYPE._serialized_start=130
  _FEATURESETALERTTYPE._serialized_end=232
  _FEATURESETFAILUREALERT._serialized_start=234
  _FEATURESETFAILUREALERT._serialized_end=315
  _FEATURESETALERTOPTIONS._serialized_start=318
  _FEATURESETALERTOPTIONS._serialized_end=506
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from typing import List

from qwak.llmops.prompt.chat.message import BaseMessage
from qwak.llmops.prompt.value import PromptValue


@dataclass
class ChatPromptValue(PromptValue):
    messages: List[BaseMessage]



from enum import Enum
from typing import TypeVar

from .base_input_adapter import BaseInputAdapter

T = TypeVar("T")


class ProtobufFlavor(Enum):
    GOOGLE_PROTO = 1
    BETTERPROTO = 2


class ProtoInputAdapter(BaseInputAdapter):
    def __init__(
        self, message: T, flavor: ProtobufFlavor = ProtobufFlavor.GOOGLE_PROTO
    ):
        self.message: T = message
        self.flavor = flavor

    def extract_user_func_arg(self, data: bytes) -> T:
        try:
            model_input = self.message()
            if self.flavor is ProtobufFlavor.GOOGLE_PROTO:
                model_input.ParseFromString(data)

            if self.flavor is ProtobufFlavor.BETTERPROTO:
                model_input.parse(data)

            return model_input
        except Exception as e:
            raise ValueError(f"Failed to serialize Proto message. Error is {e}")



import inspect
import os
from typing import Union

from qwak.feature_store.online.client import OnlineClient
from qwak.model.base import QwakModel
from contextlib import contextmanager

from .adapters.input import get_input_adapter
from .adapters.output import get_output_adapter

_FS_EXTRACTION = "_fs_extraction"
_DF = "df"
_EXTRACTED_DF = "extracted_df"


def run_local(model: QwakModel, payload: Union[str, bytes]):
    """
    Invokes the .build, .initialize_model, and in order and then invokes the input adapter, calls the predict method
    and invokes the output adapter.
    :param model: the model to run locally
    :param payload: a string or bytes with the input data
    :return: a string or bytes with the model output
    """
    if not (hasattr(model, "initialized") and model.initialized):
        with _set_local_mode():
            model.build()
            model.initialize_model()
            setattr(model, "initialized", True)
    input_adapter = get_input_adapter(model)
    output_adapter = get_output_adapter(model)
    input_data = input_adapter.extract_user_func_args(payload)

    if getattr(model.predict, _FS_EXTRACTION, False):
        args_list = list(inspect.signature(model.predict).parameters.keys())
        if (_DF or _EXTRACTED_DF) not in args_list:
            raise ValueError(
                """
                Missing 'extracted_df' or 'df' arguments in function invocation, even though 'feature_extraction' flag is true.
                manner:
                >>> @api(feature_extraction=True)
                >>> def predict(df: pd.DataFrame, extracted_df: pd.DataFrame):
                >>>    ...
                >>>    ...
                """
            )

        extracted_df = _extract_online_features(model, input_data)
        output_data = model.predict(input_data, extracted_df)
    else:
        output_data = model.predict(input_data)

    return output_adapter.pack_user_func_return_value(output_data)


def _extract_online_features(model, df):
    return OnlineClient().get_feature_values(
        schema=model.schema(), df=df, model_name="Test Model"
    )


@contextmanager
def _set_local_mode():
    os.environ["QWAK_IS_RUN_LOCAL"] = "true"
    try:
        yield
    finally:
        del os.environ["QWAK_IS_RUN_LOCAL"]



from pathlib import Path
from typing import Optional

import grpc
from _qwak_proto.qwak.file_versioning.file_versioning_pb2 import (
    FileTagFilter,
    FileTagSpec,
)
from _qwak_proto.qwak.file_versioning.file_versioning_service_pb2 import (
    GetModelFileTagsRequest,
    RegisterFileTagRequest,
)
from _qwak_proto.qwak.file_versioning.file_versioning_service_pb2_grpc import (
    FileVersioningManagementServiceStub,
)
from dependency_injector.wiring import Provide
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer


class FileVersioningManagementClient:
    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._file_management_service = FileVersioningManagementServiceStub(
            grpc_channel
        )

    def register_file_tag(
        self, model_id: str, tag: str, file_path: str, build_id: Optional[str] = ""
    ) -> None:
        """
        Register file tag to service
        Args:
            model_id: model id to save tag by.
            file_path: The file path
            tag: tag to save the file under.
            build_id: build id to save tag by.

        Returns:

        """
        try:
            file_extension = Path(file_path).suffix.replace(".", "")

            self._file_management_service.RegisterFileTag(
                RegisterFileTagRequest(
                    file_tag_spec=(
                        FileTagSpec(
                            build_id=build_id,
                            model_id=model_id,
                            tag=tag,
                            extension_type=file_extension,
                        )
                    )
                )
            )
        except grpc.RpcError as e:
            if e.args[0].code != grpc.StatusCode.ALREADY_EXISTS:
                raise QwakException(
                    f"Failed to register file tag, error is {e.details()}"
                )
            else:
                raise e

    def get_model_file_tags(
        self, model_id: str, build_id: str, file_tag_filter: FileTagFilter = None
    ):
        try:
            return self._file_management_service.GetModelFileTags(
                GetModelFileTagsRequest(
                    model_id=model_id, build_id=build_id, filter=file_tag_filter
                )
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to list model file tags, error is {e.details()}"
            )



import grpc
from _qwak_proto.qwak.feature_store.jobs.v1.job_service_pb2 import (
    GetLatestJobRequest,
    GetLatestJobResponse,
    GetLatestSuccessfulJobRequest,
    GetLatestSuccessfulJobResponse,
)
from _qwak_proto.qwak.feature_store.jobs.v1.job_service_pb2_grpc import JobServiceStub
from dependency_injector.wiring import Provide
from qwak.exceptions import QwakException, QwakNotFoundException
from qwak.inner.di_configuration import QwakContainer


class FeatureSetsJobRegistryClient:
    """
    Used for interacting with Feature Registry endpoints
    """

    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._job_registry = JobServiceStub(grpc_channel)

    def get_latest_successful_job(
        self, featureset_id: str, environment_id: str
    ) -> GetLatestSuccessfulJobResponse:
        """
        Args:
            featureset_id: The id of the requested featureset
            environment_id: The environment id of the requested featureset

        Returns:
            The response of the latest successful job
        """
        try:
            get_latest_successful_job_request = GetLatestSuccessfulJobRequest(
                featureset_id=featureset_id, environment_id=environment_id
            )
            return self._job_registry.GetLatestSuccessfulJob(
                get_latest_successful_job_request
            )
        except grpc.RpcError as e:
            if e.args[0].code == grpc.StatusCode.NOT_FOUND:
                raise QwakNotFoundException(
                    f"Resource was not found, error is {repr(e)}"
                )
            raise QwakException(
                f"Failed to get latest successful job, error is {repr(e)}"
            )

    def get_latest_job(
        self, featureset_id: str, environment_id: str
    ) -> GetLatestJobResponse:
        """
        Args:
            featureset_id: The id of the requested featureset
            environment_id: The environment id of the requested featureset

        Returns:
            The response of the latest successful job
        """
        try:
            get_latest_job_request = GetLatestJobRequest(
                featureset_id=featureset_id, environment_id=environment_id
            )
            return self._job_registry.GetLatestJob(get_latest_job_request)
        except grpc.RpcError as e:
            if e.args[0].code == grpc.StatusCode.NOT_FOUND:
                raise QwakNotFoundException(
                    f"Resource was not found, error is {repr(e)}"
                )
            raise QwakException(f"Failed to get latest job, error is {repr(e)}")



import logging
import logging.config
import os
from logging.handlers import RotatingFileHandler
from pathlib import Path
from typing import Optional

import yaml
from qwak.exceptions import QwakException

DEFAULT_LOGGER_NAME = "qwak"
REMOTE_LOGGER_NAME = "qwak_remote"
MODEL_LOGGER_NAME = "qwak_model"
FEATURE_STORE_LOGGER_NAME = "feature_store"
BUILD_LOCAL_LOGGER_NAME = "build_local"
DOCKER_INTERNAL_LOGGER_NAME = "docker_internal"

ENVIRON_LOGGER_TYPE = "LOGGER_TYPE"

BUILD_LOCAL_FILE_HANDLER_NAME = "build_log_file_handler"
FILE_HANDLER_NAME = "file_handler"
CONSOLE_HANDLER_NAME = "console"
REMOTE_CONSOLE_HANDLER_NAME = "remote_console"

DEFINED_LOGGER_NAMES = {
    DEFAULT_LOGGER_NAME,
    REMOTE_LOGGER_NAME,
    MODEL_LOGGER_NAME,
    FEATURE_STORE_LOGGER_NAME,
    BUILD_LOCAL_LOGGER_NAME,
    DOCKER_INTERNAL_LOGGER_NAME,
}

VERBOSITY_LEVEL_MAPPING = {0: logging.CRITICAL, 1: logging.INFO, 2: logging.DEBUG}
REVERSED_VERBOSITY_LEVEL_MAPPING = {
    value: key for key, value in VERBOSITY_LEVEL_MAPPING.items()
}

AIRFLOW_ENV_FLAG = "AIRFLOW__LOGGING__REMOTE_LOGGING"
LOGGING_CONFIG_FILE_NAME = "logging.yml"
HANDLERS_KEY = "handlers"
FILE_HANDLER_KEY = "file_handler"
FILE_NAME = "filename"
DISABLE_EXISTING_LOGGERS_KEY = "disable_existing_loggers"
LOGFILE_DEFAULT_NAME = "qwak.log"

LOGGER_CONFIGURATION_EXCEPTION_MESSAGE = (
    "Error in Logging Configuration. Error message: {e}"
)
LOGGER_NOT_FOUND_MESSAGE = (
    "Failed to get requested logger name {logger_name}. Using default logger"
)
ANOTHER_LOGGER_FOUND_MESSAGE = (
    "Another logger is already enabled, not changing configuration"
)
LOGGER_HANDLER_ADDITION_NOT_FOUND_MESSAGE = (
    "Tried to set orphan loggers handlers with a non-existing logger name handlers"
)
DEFAULT_LOGGER_PATH = Path.home() / ".qwak" / "log" / LOGFILE_DEFAULT_NAME


def setup_qwak_logger(
    logs_folder: str = None,
    log_file_name: str = LOGFILE_DEFAULT_NAME,
    logger_name_handler_addition: str = None,
    disable_existing_loggers: bool = False,
):
    """Setup qwak logger:
            1. Rotating file in $HOME/.qwak/log/sdk.log (10MB * 5 files) (DEBUG level)
            2. Stdout logger with colored logs. (INFO level)

    Args:
        logs_folder: Folder where logs will be stored
        log_file_name: The name of the log file. Default: qwak.log
        logger_name_handler_addition:
            Logger name which the handlers of will be appended to all loggers which have handlers
            Overriding stdout stream handler if exists
        disable_existing_loggers: disables all existing loggers

    Raises:
        QwakException: If loading logging.yml fails or the preparation of the logging environment raises an exception

    Notes:
        1. https://docs.python.org/3/library/logging.html#logging-levels
    """

    logs_folder = logs_folder if logs_folder else DEFAULT_LOGGER_PATH
    config_file = Path(__file__).parent / LOGGING_CONFIG_FILE_NAME
    if not non_qwak_logger_enabled():
        # Creating log directory
        log_path = _create_logs_path(logs_folder)
        _load_config(log_file_name, config_file, disable_existing_loggers, log_path)
        logger = get_qwak_logger()

        if logger_name_handler_addition:
            if logger_name_handler_addition in logging.Logger.manager.loggerDict:
                _add_logger_handlers(logger_name_handler_addition)
            else:
                logger.warning(LOGGER_HANDLER_ADDITION_NOT_FOUND_MESSAGE)

    else:
        logger = logging.getLogger(__file__)
        logger.info(ANOTHER_LOGGER_FOUND_MESSAGE)


def _create_logs_path(logs_folder: str) -> Path:
    log_path = Path(logs_folder)
    log_path.mkdir(parents=True, exist_ok=True)
    return log_path


def _load_config(
    log_file_name: str,
    config_file: Path,
    disable_existing_loggers: bool,
    log_path: Path,
) -> None:
    with config_file.open(mode="rt") as f:
        try:
            # Load logger configuration
            config = yaml.safe_load(f.read())
            config[HANDLERS_KEY][FILE_HANDLER_KEY][FILE_NAME] = str(
                log_path / log_file_name
            )
            config[HANDLERS_KEY][BUILD_LOCAL_FILE_HANDLER_NAME][FILE_NAME] = str(
                log_path / log_file_name
            )
            config[DISABLE_EXISTING_LOGGERS_KEY] = disable_existing_loggers

            logging.config.dictConfig(config)

        except Exception as e:
            raise QwakException(LOGGER_CONFIGURATION_EXCEPTION_MESSAGE.format(e=e))


def _add_logger_handlers(logger_name: str) -> None:
    """
    Add a specific logger handlers to all loggers
    Override loggers StreamHandler handlers if the input logger has a StreamHandler

    :param logger_name: logger name which consists of the handlers we wish to set
    """

    requested_logger_handlers = logging.getLogger(logger_name).handlers
    replace_stdout_handler = any(
        [
            handler
            for handler in requested_logger_handlers
            if isinstance(handler, logging.StreamHandler)
        ]
    )

    for existing_logger in [
        logger
        for logger in logging.Logger.manager.loggerDict.values()
        if not isinstance(logger, logging.PlaceHolder)
    ]:
        if existing_logger.handlers:
            if replace_stdout_handler:
                existing_handlers = list(
                    filter(
                        lambda h: not isinstance(h, logging.StreamHandler),
                        existing_logger.handlers,
                    )
                )
            else:
                existing_handlers = existing_logger.handlers
            existing_logger.handlers = existing_handlers + requested_logger_handlers


def get_qwak_logger(
    logger_name: Optional[str] = None,
    fallback_logger_name: Optional[str] = DEFAULT_LOGGER_NAME,
) -> logging.Logger:
    """Get qwak logger (Singleton)
    :param logger_name: logger name to get
    :param fallback_logger_name: fallback logger name to get if logger_name is not defined

    Returns:
        logging.Logger: Qwak logger.
    """
    if not logger_name:
        logger_name = get_qwak_logger_name(fallback_logger_name)

    if (logger_name not in DEFINED_LOGGER_NAMES) and not non_qwak_logger_enabled():
        print(LOGGER_NOT_FOUND_MESSAGE.format(logger_name=logger_name))

    return logging.getLogger(logger_name)


def get_qwak_logger_name(fallback_logger_name: str) -> str:
    return os.getenv(ENVIRON_LOGGER_TYPE, fallback_logger_name)


def non_qwak_logger_enabled() -> bool:
    return os.getenv(AIRFLOW_ENV_FLAG) is not None


def copy_file_handler_from_existing(
    handler: RotatingFileHandler, log_file: Path
) -> RotatingFileHandler:
    return RotatingFileHandler(
        log_file,
        mode=handler.mode,
        maxBytes=int(handler.maxBytes),
        backupCount=int(handler.backupCount),
        encoding=handler.encoding,
        delay=handler.delay,
    )


def set_qwak_logger_stdout_verbosity_level(verbose: int, format: str = "text"):
    """Set qwak stdout to verbose (a.k.a DEBUG level)

    Args:
        verbose: Log verbosity level - 0: WARNING, 1:INFO, 2: DEBUG


    Notes:
        1. https://docs.python.org/3/library/logging.html#logging-levels
    """
    if format == "json":
        verbose = 0
    logger: logging.Logger = get_qwak_logger()
    logger.setLevel(VERBOSITY_LEVEL_MAPPING[verbose])
    for handler in logger.handlers:
        if isinstance(handler, logging.StreamHandler):
            handler.setLevel(VERBOSITY_LEVEL_MAPPING[verbose])


def get_qwak_logger_verbosity_level() -> Optional[int]:
    """Get current Qwak logger level.

    Returns:
        int: Qwak logger level 10 < level < 50.

    Notes:
        1. https://docs.python.org/3/library/logging.html#logging-levels
        2. when we update the log level through set_qwak_logger_stdout_verbosity_level we update all handler levels
           thus returning the first stream handler should be correct
    """

    logger: logging.Logger = get_qwak_logger()

    for handler in logger.handlers:
        if isinstance(handler, logging.StreamHandler):
            return logging.getLevelName(handler.level)


def set_handler_verbosity(logger: logging.Logger, handler_name: str, log_level: int):
    handler = get_handler_from_logger(logger, handler_name)
    handler.setLevel(log_level)


def get_handler_from_logger(
    logger: logging.Logger, handler_name: str
) -> logging.Handler:
    matching_handlers = list(
        filter(lambda h: h.get_name() == handler_name, logger.handlers)
    )
    if len(matching_handlers) == 0 and not non_qwak_logger_enabled:
        raise QwakException(
            f"Error in setting log file. Error message: handler of name {handler_name} was not found in logger"
        )
    elif len(matching_handlers) > 1:
        raise QwakException(
            f"Error in setting log file. Error message: handler of name {handler_name} was found more than once "
            f"in logger"
        )

    return matching_handlers[0]


def set_file_handler_log_file(
    logger: logging.Logger, handler_name: str, log_file: Path
):
    existing_handler = get_handler_from_logger(logger, handler_name)
    if type(existing_handler) != RotatingFileHandler:
        raise QwakException(
            f"Error in setting log file. Error message: handler of name {handler_name} is not a file logger handler"
        )
    replacement_handler: RotatingFileHandler = copy_file_handler_from_existing(
        existing_handler, log_file
    )
    logger.removeHandler(existing_handler)
    logger.addHandler(replacement_handler)



from typing import Optional

from _qwak_proto.qwak.logging.log_filter_pb2 import LogText, SearchFilter
from _qwak_proto.qwak.logging.log_reader_service_pb2 import (
    ReadLogsRequest,
    ReadLogsResponse,
)
from _qwak_proto.qwak.logging.log_reader_service_pb2_grpc import LogReaderServiceStub
from _qwak_proto.qwak.logging.log_source_pb2 import (
    InferenceExecutionSource,
    LogSource,
    ModelRuntimeSource,
    RemoteBuildSource,
)
from grpc import RpcError
from qwak.clients.administration.eco_system.client import EcosystemClient
from qwak.exceptions import QwakException
from qwak.inner.tool.grpc.grpc_tools import create_grpc_channel


class LoggingClient:
    """
    Used for interacting with Logging endpoint
    """

    def __init__(
        self,
        endpoint_url: Optional[str] = None,
        enable_ssl: bool = True,
        environment_id: Optional[str] = None,
    ):
        if endpoint_url is None:
            user_context = EcosystemClient().get_authenticated_user_context().user
            if environment_id is None:
                environment_id = user_context.account_details.default_environment_id

            if environment_id not in user_context.account_details.environment_by_id:
                raise QwakException(
                    f"Configuration for environment [{environment_id}] was not found"
                )

            endpoint_url = user_context.account_details.environment_by_id[
                environment_id
            ].configuration.edge_services_url

        self._channel = create_grpc_channel(url=endpoint_url, enable_ssl=enable_ssl)

        self._logging_service = LogReaderServiceStub(self._channel)

    def read_build_logs(
        self,
        build_id=None,
        before_offset=None,
        after_offset=None,
        max_number_of_results=None,
        log_text_filter=None,
    ):
        try:
            response = self.read_logs(
                source=LogSource(remote_build=RemoteBuildSource(build_id=build_id)),
                before_offset=before_offset,
                after_offset=after_offset,
                log_text_filter=log_text_filter,
                max_number_of_results=max_number_of_results,
            )

            return response
        except QwakException as e:
            raise QwakException(f"Failed to fetch build logs, error is [{e}]")

    def read_model_runtime_logs(
        self,
        build_id=None,
        deployment_id=None,
        before_offset=None,
        after_offset=None,
        max_number_of_results=None,
        log_text_filter=None,
    ) -> ReadLogsResponse:
        try:
            response = self.read_logs(
                source=LogSource(
                    model_runtime=ModelRuntimeSource(
                        build_id=build_id, deployment_id=deployment_id
                    )
                ),
                before_offset=before_offset,
                after_offset=after_offset,
                log_text_filter=log_text_filter,
                max_number_of_results=max_number_of_results,
            )

            return response
        except QwakException as e:
            raise QwakException(f"Failed to fetch runtime logs, error is [{e}]")

    def read_execution_models_logs(
        self,
        execution_id,
        before_offset=None,
        after_offset=None,
        max_number_of_results=None,
        log_text_filter=None,
    ) -> ReadLogsResponse:
        try:
            response = self.read_logs(
                source=LogSource(
                    inference_execution=InferenceExecutionSource(
                        inference_job_id=execution_id
                    )
                ),
                before_offset=before_offset,
                after_offset=after_offset,
                log_text_filter=log_text_filter,
                max_number_of_results=max_number_of_results,
            )

            return response
        except QwakException as e:
            raise QwakException(f"Failed to fetch execution logs, error is [{e}]")

    def read_logs(
        self,
        source,
        before_offset,
        after_offset,
        max_number_of_results,
        log_text_filter,
    ):
        try:
            response = self._logging_service.ReadLogs(
                ReadLogsRequest(
                    source=source,
                    before_offset=before_offset,
                    after_offset=after_offset,
                    search_filter=SearchFilter(
                        log_text_filter=LogText(contains=log_text_filter)
                    ),
                    max_number_of_results=max_number_of_results,
                )
            )
            return response
        except RpcError as e:
            raise QwakException(
                f"Failed grpc read logs request, grpc error is "
                f"[{e.details() if e.details() else e.code()}]"
            )
